@@ -4,8 +4,7 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef AKREGATOR_CONFIG_PLUGINS_H
-#define AKREGATOR_CONFIG_PLUGINS_H
+#pragma once
 
 #include <KCModule>
 #include <QVariant>
@@ -31,4 +30,3 @@ private:
     PimCommon::ConfigurePluginsWidget *mConfigurePluginWidget = nullptr;
 };
 }
-#endif //  AKREGATOR_CONFIG_PLUGINS_H
