@@ -7,12 +7,12 @@
  *
  */
 #include "feedstorage.h"
+#include "kcoreaddons_version.h"
 #include "plugin.h"
 #include "storage.h"
 #include "storagefactory.h"
 #include "storagefactoryregistry.h"
 #include <KLocalizedString>
-
 #include <Syndication/Atom/Atom>
 #include <Syndication/Constants>
 
@@ -248,7 +248,8 @@ static void writeItem(FeedStorage *storage, const QString &guid, QXmlStreamWrite
     writeAuthor(storage->authorName(guid), storage->authorUri(guid), storage->authorEMail(guid), writer);
 
     bool hasEnc = false;
-    QString encUrl, encType;
+    QString encUrl;
+    QString encType;
     int encLength = 0;
     storage->enclosure(guid, hasEnc, encUrl, encType, encLength);
     if (hasEnc) {
