@@ -7,8 +7,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef AKREGATOR_ARTICLE_H
-#define AKREGATOR_ARTICLE_H
+#pragma once
 
 #include "akregator_export.h"
 #include "types.h"
@@ -21,7 +20,7 @@ class QString;
 
 template<class T> class QList;
 
-typedef unsigned int uint;
+using uint = unsigned int;
 
 class QUrl;
 
@@ -29,7 +28,7 @@ namespace Syndication
 {
 class Enclosure;
 class Item;
-typedef QSharedPointer<Item> ItemPtr;
+using ItemPtr = QSharedPointer<Item>;
 }
 
 namespace Akregator
@@ -137,4 +136,3 @@ private:
 };
 } // namespace Akregator
 Q_DECLARE_TYPEINFO(Akregator::Article, Q_MOVABLE_TYPE);
-#endif // AKREGATOR_ARTICLE_H
