@@ -12,10 +12,14 @@
 
 #include <QObject>
 
+#include <memory>
+
 class QWidget;
 
 namespace Akregator
 {
+class CommandPrivate;
+
 class AKREGATORINTERFACES_EXPORT Command : public QObject
 {
     Q_OBJECT
@@ -43,8 +47,7 @@ protected:
     void done();
 
 private:
-    class Private;
-    Private *const d;
+    std::unique_ptr<CommandPrivate> const d;
 };
 }
 
