@@ -5,8 +5,7 @@
 
     SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
-#ifndef AKREGATOR_ABSTRACTSELECTIONCONTROLLER_H
-#define AKREGATOR_ABSTRACTSELECTIONCONTROLLER_H
+#pragma once
 
 #include <QObject>
 
@@ -110,4 +109,3 @@ Q_SIGNALS:
 };
 } // namespace Akregator
 
-#endif // AKREGATOR_ABSTRACTSELECTIONCONTROLLER_H
