@@ -6,8 +6,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef AKREGATOR_ACTIONMANAGER_H
-#define AKREGATOR_ACTIONMANAGER_H
+#pragma once
 
 #include <QObject>
 
@@ -53,4 +52,3 @@ private:
 };
 } // namespace Akregator
 
-#endif // AKREGATOR_ACTIONMANAGER_H
