@@ -93,7 +93,7 @@ private:
 class ActionManagerImpl::ActionManagerImplPrivate
 {
 public:
-    QString quickSearchLineText() const;
+    Q_REQUIRED_RESULT QString quickSearchLineText() const;
     NodeSelectVisitor *nodeSelectVisitor = nullptr;
     ArticleListView *articleList = nullptr;
     SubscriptionListView *subscriptionListView = nullptr;
@@ -159,8 +159,6 @@ ActionManagerImpl::ActionManagerImpl(Part *part, QObject *parent)
 ActionManagerImpl::~ActionManagerImpl()
 {
     delete d->nodeSelectVisitor;
-    delete d;
-    d = nullptr;
 }
 
 void ActionManagerImpl::setTrayIcon(TrayIcon *trayIcon)
@@ -663,7 +661,7 @@ KActionCollection *ActionManagerImpl::actionCollection() const
 
 QAction *ActionManagerImpl::action(const QString &name)
 {
-    return d->actionCollection != nullptr ? d->actionCollection->action(name) : nullptr;
+    return d->actionCollection ? d->actionCollection->action(name) : nullptr;
 }
 
 void ActionManagerImpl::setArticleActionsEnabled(bool enabled){
