@@ -9,7 +9,6 @@
 
 #include "akregator_part.h"
 #include "akregator_debug.h"
-#include "kcmutils_version.h"
 
 #include <MessageViewer/MessageViewerSettings>
 
@@ -23,6 +22,7 @@
 #include "feedlist.h"
 #include "fetchqueue.h"
 #include "framemanager.h"
+#include "kcoreaddons_version.h"
 #include "kernel.h"
 #include "loadfeedlistcommand.h"
 #include "mainwidget.h"
@@ -37,13 +37,12 @@
 #include "utils.h"
 #include "widgets/akregatorcentralwidget.h"
 #include <KConfig>
+#include <KIO/FileCopyJob>
 #include <KMessageBox>
 #include <KNotifyConfigWidget>
-#include <KPluginLoader>
 #include <KPluginMetaData>
 #include <PimCommon/BroadcastStatus>
 #include <QFileDialog>
-#include <kio/filecopyjob.h>
 
 #include <KCMultiDialog>
 #include <KIO/StoredTransferJob>
@@ -609,14 +608,9 @@ void Part::showOptions()
         if (TrayIcon::getInstance()) {
             connect(m_dialog, qOverload<>(&KCMultiDialog::configCommitted), TrayIcon::getInstance(), &TrayIcon::settingsChanged);
         }
-
-        const QVector<KPluginMetaData> availablePlugins = KPluginLoader::findPlugins(QStringLiteral("pim/kcms/akregator"));
+        const QVector<KPluginMetaData> availablePlugins = KPluginMetaData::findPlugins(QStringLiteral("pim/kcms/akregator"));
         for (const KPluginMetaData &metaData : availablePlugins) {
-#if KCMUTILS_VERSION >= QT_VERSION_CHECK(5, 84, 0)
             m_dialog->addModule(metaData);
-#else
-            m_dialog->addModule(metaData.pluginId());
-#endif
         }
     }
 
