@@ -187,7 +187,7 @@ void ArticleViewerWebEngine::slotSaveLinkAs()
     auto dlg = new QFileDialog(this);
     dlg->setAttribute(Qt::WA_DeleteOnClose);
     dlg->setAcceptMode(QFileDialog::AcceptSave);
-    dlg->setWindowTitle(i18n("Save As"));
+    dlg->setWindowTitle(i18nc("@title:window", "Save As"));
     dlg->setOption(QFileDialog::DontConfirmOverwrite, false);
     dlg->selectFile(url.fileName());
     dlg->show();
@@ -412,7 +412,12 @@ void ArticleViewerWebEngine::forwardMouseReleaseEvent(QMouseEvent *event)
 
 bool ArticleViewerWebEngine::urlIsAMalwareButContinue()
 {
-    if (KMessageBox::No == KMessageBox::warningYesNo(this, i18n("This web site is a malware, do you want to continue to show it?"), i18n("Malware"))) {
+    if (KMessageBox::No
+        == KMessageBox::warningYesNo(this,
+                                     i18n("This web site is a malware, do you want to continue to show it?"),
+                                     i18n("Malware"),
+                                     KStandardGuiItem::cont(),
+                                     KStandardGuiItem::cancel())) {
         return false;
     }
     return true;
