@@ -10,11 +10,14 @@
 
 #include "command.h"
 
+#include <memory>
+
 namespace Akregator
 {
 class Folder;
 class SubscriptionListView;
 class TreeNode;
+class CreateFolderCommandPrivate;
 
 class CreateFolderCommand : public Command
 {
@@ -32,8 +35,8 @@ private:
     void doAbort() override;
 
 private:
-    class Private;
-    Private *const d;
+    friend class CreateFolderCommandPrivate;
+    std::unique_ptr<CreateFolderCommandPrivate> const d;
 };
 }
 
