@@ -12,10 +12,13 @@
 
 #include <QSharedPointer>
 
+#include <memory>
+
 namespace Akregator
 {
 class FeedList;
 class SubscriptionListView;
+class EditSubscriptionCommandPrivate;
 
 class EditSubscriptionCommand : public Command
 {
@@ -36,8 +39,8 @@ private:
     void doAbort() override;
 
 private:
-    class Private;
-    Private *const d;
+    friend class EditSubscriptionCommandPrivate;
+    std::unique_ptr<EditSubscriptionCommandPrivate> const d;
 };
 }
 
