@@ -14,9 +14,12 @@
 
 #include <QWeakPointer>
 
+#include <memory>
+
 namespace Akregator
 {
 class FeedList;
+class ExpireItemsCommandPrivate;
 
 class ExpireItemsCommand : public Command
 {
@@ -36,8 +39,8 @@ private:
     void doAbort() override;
 
 private:
-    class Private;
-    Private *const d;
+    friend class ExpireItemsCommandPrivate;
+    std::unique_ptr<ExpireItemsCommandPrivate> const d;
 };
 }
 
