@@ -12,11 +12,14 @@
 
 #include <QWeakPointer>
 
+#include <memory>
+
 class QDomDocument;
 
 namespace Akregator
 {
 class FeedList;
+class ImportFeedListCommandPrivate;
 
 class ImportFeedListCommand : public Command
 {
@@ -39,8 +42,8 @@ private:
     void doAbort() override;
 
 private:
-    class Private;
-    Private *const d;
+    friend class ImportFeedListCommandPrivate;
+    std::unique_ptr<ImportFeedListCommandPrivate> const d;
 };
 }
 
