@@ -12,6 +12,8 @@
 
 #include <QSharedPointer>
 
+#include <memory>
+
 class QDomDocument;
 
 namespace Akregator
@@ -22,6 +24,7 @@ class Storage;
 }
 
 class FeedList;
+class LoadFeedListCommandPrivate;
 
 class LoadFeedListCommand : public Command
 {
@@ -42,8 +45,8 @@ private:
     void doAbort() override;
 
 private:
-    class Private;
-    Private *const d;
+    friend class LoadFeedListCommandPrivate;
+    std::unique_ptr<LoadFeedListCommandPrivate> const d;
 };
 }
 
