@@ -4,8 +4,7 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef CRASHWIDGET_H
-#define CRASHWIDGET_H
+#pragma once
 
 #include <QWidget>
 namespace Akregator
@@ -17,7 +16,7 @@ public:
     enum CrashAction { RestoreSession = 0, NotRestoreSession, AskMeLater };
 
     explicit CrashWidget(QWidget *parent = nullptr);
-    ~CrashWidget();
+    ~CrashWidget() override;
 
 Q_SIGNALS:
     void restoreSession(Akregator::CrashWidget::CrashAction type);
@@ -29,4 +28,3 @@ private Q_SLOTS:
 };
 }
 
-#endif
