@@ -6,8 +6,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef AKREGATOR_STORAGEFACTORYDUMMYIMPL_H
-#define AKREGATOR_STORAGEFACTORYDUMMYIMPL_H
+#pragma once
 
 #include "akregatorpart_export.h"
 #include "storagefactory.h"
@@ -37,4 +36,3 @@ public:
 } // namespace Backend
 } // namespace Akregator
 
-#endif // AKREGATOR_STORAGEFACTORYDUMMYIMPL_H
