@@ -19,7 +19,6 @@
 #include "subscriptionlistjobs.h"
 #include <KLocalizedString>
 #include <limits>
-#include <memory>
 
 #include <QElapsedTimer>
 #include <QHash>
@@ -28,19 +27,19 @@
 #include <qdom.h>
 
 using namespace Akregator;
-class Q_DECL_HIDDEN FeedList::Private
+class Akregator::FeedListPrivate
 {
     FeedList *const q;
 
 public:
-    Private(Backend::Storage *st, FeedList *qq);
+    FeedListPrivate(Backend::Storage *st, FeedList *qq);
 
     Akregator::Backend::Storage *storage;
     QList<TreeNode *> flatList;
     Folder *rootNode;
     QHash<uint, TreeNode *> idMap;
-    AddNodeVisitor *addNodeVisitor;
-    RemoveNodeVisitor *removeNodeVisitor;
+    FeedList::AddNodeVisitor *addNodeVisitor;
+    FeedList::RemoveNodeVisitor *removeNodeVisitor;
     QHash<QString, QList<Feed *>> urlMap;
     mutable int unreadCache;
 };
@@ -143,12 +142,12 @@ private:
     FeedList *m_list;
 };
 
-FeedList::Private::Private(Backend::Storage *st, FeedList *qq)
+FeedListPrivate::FeedListPrivate(Backend::Storage *st, FeedList *qq)
     : q(qq)
     , storage(st)
     , rootNode(nullptr)
-    , addNodeVisitor(new AddNodeVisitor(q))
-    , removeNodeVisitor(new RemoveNodeVisitor(q))
+    , addNodeVisitor(new FeedList::AddNodeVisitor(q))
+    , removeNodeVisitor(new FeedList::RemoveNodeVisitor(q))
     , unreadCache(-1)
 {
     Q_ASSERT(storage);
@@ -156,7 +155,7 @@ FeedList::Private::Private(Backend::Storage *st, FeedList *qq)
 
 FeedList::FeedList(Backend::Storage *storage)
     : QObject(nullptr)
-    , d(new Private(storage, this))
+    , d(new FeedListPrivate(storage, this))
 {
     auto rootNode = new Folder(i18n("All Feeds"));
     rootNode->setId(1);
@@ -296,7 +295,6 @@ FeedList::~FeedList()
     setRootNode(nullptr);
     delete d->addNodeVisitor;
     delete d->removeNodeVisitor;
-    delete d;
 }
 
 const Akregator::Feed *FeedList::findByURL(const QString &feedURL) const
