@@ -7,8 +7,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef AKREGATOR_FOLDER_H
-#define AKREGATOR_FOLDER_H
+#pragma once
 
 #include "akregator_export.h"
 #include "treenode.h"
@@ -192,4 +191,3 @@ private:
 };
 } // namespace Akregator
 
-#endif // AKREGATOR_FOLDER_H
