@@ -22,26 +22,11 @@
 using namespace Syndication;
 using namespace Akregator;
 
-class Q_DECL_HIDDEN ArticleFormatter::Private
-{
-public:
-    explicit Private();
-    class SummaryVisitor;
-};
-
-ArticleFormatter::Private::Private()
-{
-}
-
 ArticleFormatter::ArticleFormatter()
-    : d(new Private())
 {
 }
 
-ArticleFormatter::~ArticleFormatter()
-{
-    delete d;
-}
+ArticleFormatter::~ArticleFormatter() = default;
 
 QString ArticleFormatter::formatEnclosure(const Enclosure &enclosure)
 {
