@@ -15,6 +15,7 @@ namespace Akregator
 {
 class Article;
 class TreeNode;
+class ArticleFormatterPrivate;
 
 class ArticleFormatter
 {
@@ -32,8 +33,6 @@ public:
     static QString formatEnclosure(const Syndication::Enclosure &enclosure);
 
 private:
-    class Private;
-    Private *const d;
     Q_DISABLE_COPY(ArticleFormatter)
 };
 } // namespace Akregator
