@@ -4,8 +4,7 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef DOWNLOADFEEDICONJOB_H
-#define DOWNLOADFEEDICONJOB_H
+#pragma once
 
 #include <QObject>
 #include <QUrl>
@@ -18,7 +17,7 @@ class AKREGATOR_EXPORT DownloadFeedIconJob : public QObject
     Q_OBJECT
 public:
     explicit DownloadFeedIconJob(QObject *parent = nullptr);
-    ~DownloadFeedIconJob();
+    ~DownloadFeedIconJob() override;
     Q_REQUIRED_RESULT bool start();
     Q_REQUIRED_RESULT bool canStart() const;
 
@@ -37,4 +36,3 @@ private:
 };
 }
 
-#endif // DOWNLOADFEEDICONJOB_H
