@@ -8,7 +8,7 @@
 
 #pragma once
 
-#include <kio/job.h>
+#include <KIO/Job>
 #include <kparts/mainwindow.h>
 
 #include <QPointer>
@@ -81,6 +81,7 @@ private Q_SLOTS:
 
 private:
     void updateHamburgerMenu();
+    void slotToggleMenubar(bool dontShowWarning);
     QPointer<Akregator::Part> m_part;
     KSqueezedTextLabel *const m_statusLabel;
     KHamburgerMenu *mHamburgerMenu = nullptr;
