@@ -126,7 +126,7 @@ Akregator::SubscriptionListView::SubscriptionListView(QWidget *parent)
     setRootIsDecorated(false);
     setAlternatingRowColors(true);
     setContextMenuPolicy(Qt::CustomContextMenu);
-    setDragDropMode(QAbstractItemView::DragDrop);
+    setDragDropMode(Settings::lockFeedsInPlace() ? QAbstractItemView::NoDragDrop : QAbstractItemView::DragDrop);
     setDropIndicatorShown(true);
     setAcceptDrops(true);
     setUniformRowHeights(true);
@@ -393,6 +393,17 @@ void SubscriptionListView::slotSetHideReadFeeds(bool setting)
     filter->setDoFilter(setting);
 }
 
+void SubscriptionListView::slotSetLockFeedsInPlace(bool setting)
+{
+    if (!model()) {
+        return;
+    }
+
+    setDragDropMode(setting? QAbstractItemView::NoDragDrop : QAbstractItemView::DragDrop);
+
+    Settings::setLockFeedsInPlace(setting);
+}
+
 void Akregator::SubscriptionListView::slotSetAutoExpandFolders(bool setting)
 {
     Settings::setAutoExpandFolders(setting);
