@@ -6,8 +6,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef AKREGATOR_SUBSCRIPTIONLISTVIEW_H
-#define AKREGATOR_SUBSCRIPTIONLISTVIEW_H
+#pragma once
 
 #include <QAction>
 #include <QByteArray>
@@ -54,6 +53,7 @@ public Q_SLOTS:
     void slotItemDown();
 
     void slotSetHideReadFeeds(bool setting);
+    void slotSetLockFeedsInPlace(bool setting);
     void slotSetAutoExpandFolders(bool setting);
 
 Q_SIGNALS:
@@ -72,4 +72,3 @@ private:
 };
 }
 
-#endif // AKREGATOR_SUBSCRIPTIONLISTVIEW_H
