@@ -18,9 +18,9 @@
 #include <QStyleOption>
 
 #include "akregator_debug.h"
+#include <KIO/Global>
 #include <KLocalizedString>
 #include <QTabBar>
-#include <kio/global.h>
 
 #include "actionmanager.h"
 #include "akregatorconfig.h"
@@ -32,13 +32,13 @@
 
 using namespace Akregator;
 
-class Q_DECL_HIDDEN TabWidget::Private
+class Akregator::TabWidgetPrivate
 {
 private:
     TabWidget *const q;
 
 public:
-    explicit Private(TabWidget *qq)
+    explicit TabWidgetPrivate(TabWidget *qq)
         : q(qq)
     {
     }
@@ -60,7 +60,7 @@ public:
     Frame *currentFrame();
 };
 
-void TabWidget::Private::updateTabBarVisibility()
+void TabWidgetPrivate::updateTabBarVisibility()
 {
     const bool tabBarIsHidden = ((q->count() <= 1) && !Settings::alwaysShowTabBar());
     if (tabBarIsHidden) {
@@ -75,7 +75,7 @@ void TabWidget::Private::updateTabBarVisibility()
 
 TabWidget::TabWidget(QWidget *parent)
     : QTabWidget(parent)
-    , d(new Private(this))
+    , d(new TabWidgetPrivate(this))
 {
     setMinimumSize(250, 150);
     setMovable(false);
@@ -104,10 +104,7 @@ TabWidget::TabWidget(QWidget *parent)
     d->updateTabBarVisibility();
 }
 
-TabWidget::~TabWidget()
-{
-    delete d;
-}
+TabWidget::~TabWidget() = default;
 
 void TabWidget::slotTabContextMenuRequest(const QPoint &pos)
 {
@@ -218,7 +215,7 @@ void TabWidget::slotAddFrame(Frame *frame)
     slotSetTitle(frame, frame->title());
 }
 
-Frame *TabWidget::Private::currentFrame()
+Frame *TabWidgetPrivate::currentFrame()
 {
     QWidget *w = q->currentWidget();
     Q_ASSERT(frames.value(w));
@@ -275,7 +272,7 @@ void TabWidget::slotRemoveFrame(int frameId)
 }
 
 // copied wholesale from KonqFrameTabs
-int TabWidget::Private::tabBarWidthForMaxChars(int maxLength)
+int TabWidgetPrivate::tabBarWidthForMaxChars(int maxLength)
 {
     int hframe;
     QStyleOption o;
@@ -330,13 +327,14 @@ void TabWidget::slotSetIcon(Akregator::Frame *frame, const QIcon &icon)
     setTabIcon(idx, icon);
 }
 
-void TabWidget::Private::setTitle(const QString &title, QWidget *sender)
+void TabWidgetPrivate::setTitle(const QString &title, QWidget *sender)
 {
     int senderIndex = q->indexOf(sender);
 
     q->setTabToolTip(senderIndex, QString());
 
-    int lcw = 0, rcw = 0;
+    int lcw = 0;
+    int rcw = 0;
     int tabBarHeight = q->tabBar()->sizeHint().height();
 
     QWidget *leftCorner = q->cornerWidget(Qt::TopLeftCorner);
