@@ -6,8 +6,7 @@
     SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
-#ifndef AKREGATOR_TRAYICON_H
-#define AKREGATOR_TRAYICON_H
+#pragma once
 
 #include "akregator_export.h"
 
@@ -25,7 +24,7 @@ public:
     void setEnabled(bool enabled);
 
     explicit TrayIcon(QObject *parent = nullptr);
-    ~TrayIcon();
+    ~TrayIcon() override;
 
 public Q_SLOTS:
     void settingsChanged();
@@ -38,4 +37,3 @@ private:
 };
 } // namespace Akregator
 
-#endif // AKREGATOR_TRAYICON_H
