@@ -1,19 +1,19 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "urlhandlerwebengine.h"
 #include "akregator_debug.h"
-#include <PimCommon/BroadcastStatus>
 #include "articleviewer-ng/webengine/articleviewerwebengine.h"
-#include <KLocalizedString>
-#include <QDesktopServices>
-#include <QClipboard>
-#include <QMenu>
-#include <QApplication>
 #include <KEmailAddress>
+#include <KLocalizedString>
+#include <PimCommon/BroadcastStatus>
+#include <QApplication>
+#include <QClipboard>
+#include <QDesktopServices>
+#include <QMenu>
 #include <QUrlQuery>
 using namespace Akregator;
 
@@ -54,7 +54,7 @@ QString MailToURLHandlerWebEngine::statusBarMessage(const QUrl &url, ArticleView
 bool MailToURLHandlerWebEngine::handleContextMenuRequest(const QUrl &url, const QPoint &p, ArticleViewerWebEngine *) const
 {
     if (url.scheme() == QLatin1String("mailto")) {
-        auto *menu = new QMenu();
+        auto menu = new QMenu();
         QAction *copy = menu->addAction(QIcon::fromTheme(QStringLiteral("edit-copy")), i18n("&Copy Email Address"));
 
         QAction *a = menu->exec(p);
