@@ -4,8 +4,7 @@
    SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef URLHANDLERWebEngineMANAGER_H
-#define URLHANDLERWebEngineMANAGER_H
+#pragma once
 
 #include "akregator_export.h"
 #include <QObject>
@@ -19,7 +18,7 @@ class AKREGATOR_EXPORT URLHandlerWebEngineManager : public QObject
 {
     Q_OBJECT
 public:
-    ~URLHandlerWebEngineManager();
+    ~URLHandlerWebEngineManager() override;
 
     static URLHandlerWebEngineManager *instance();
     void registerHandler(const URLHandlerWebEngine *handler);
@@ -32,9 +31,8 @@ public:
 private:
     explicit URLHandlerWebEngineManager(QObject *parent = nullptr);
     static URLHandlerWebEngineManager *self;
-    typedef QVector<const URLHandlerWebEngine *> HandlerList;
+    using HandlerList = QVector<const URLHandlerWebEngine *>;
     HandlerList mHandlers;
 };
 }
 
-#endif // URLHANDLERWebEngineMANAGER_H
